"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class ClassificationObjectTypedDict(TypedDict):
    categories: NotRequired[Dict[str, bool]]
    r"""Classifier result thresholded"""
    category_scores: NotRequired[Dict[str, float]]
    r"""Classifier result"""


class ClassificationObject(BaseModel):
    categories: Optional[Dict[str, bool]] = None
    r"""Classifier result thresholded"""

    category_scores: Optional[Dict[str, float]] = None
    r"""Classifier result"""
