"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


APIEndpoint = Literal[
    "/v1/chat/completions", "/v1/embeddings", "/v1/fim/completions", "/v1/moderations"
]
