"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .textchunk import TextChunk, TextChunkTypedDict
from mistralai_azure.types import BaseModel
from typing import List, Literal, Optional, Union
from typing_extensions import NotRequired, TypedDict


SystemMessageContentTypedDict = Union[str, List[TextChunkTypedDict]]


SystemMessageContent = Union[str, List[TextChunk]]


Role = Literal["system"]


class SystemMessageTypedDict(TypedDict):
    content: SystemMessageContentTypedDict
    role: NotRequired[Role]


class SystemMessage(BaseModel):
    content: SystemMessageContent

    role: Optional[Role] = "system"
