"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .textchunk import TextChunk, TextChunkTypedDict


ContentChunkTypedDict = TextChunkTypedDict


ContentChunk = TextChunk
