"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


FineTuneableModel = Literal[
    "open-mistral-7b",
    "mistral-small-latest",
    "codestral-latest",
    "mistral-large-latest",
    "open-mistral-nemo",
]
r"""The name of the model to fine-tune."""
