"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .classificationobject import ClassificationObject, ClassificationObjectTypedDict
from mistralai.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ClassificationResponseTypedDict(TypedDict):
    id: NotRequired[str]
    model: NotRequired[str]
    results: NotRequired[List[ClassificationObjectTypedDict]]


class ClassificationResponse(BaseModel):
    id: Optional[str] = None

    model: Optional[str] = None

    results: Optional[List[ClassificationObject]] = None
