"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai_gcp.types import BaseModel
from mistralai_gcp.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


Type = Literal["text"]


class TextChunkTypedDict(TypedDict):
    text: str
    type: Type


class TextChunk(BaseModel):
    text: str

    TYPE: Annotated[
        Annotated[Optional[Type], AfterValidator(validate_const("text"))],
        pydantic.Field(alias="type"),
    ] = "text"
