"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from mistralai.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


ArchiveFTModelOutObject = Literal["model"]


class ArchiveFTModelOutTypedDict(TypedDict):
    id: str
    object: ArchiveFTModelOutObject
    archived: NotRequired[bool]


class ArchiveFTModelOut(BaseModel):
    id: str

    OBJECT: Annotated[
        Annotated[
            Optional[ArchiveFTModelOutObject], AfterValidator(validate_const("model"))
        ],
        pydantic.Field(alias="object"),
    ] = "model"

    archived: Optional[bool] = True
