"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import UnrecognizedStr
from typing import Literal, Union


ToolTypes = Union[Literal["function"], UnrecognizedStr]
